==> estateplat-common-1.2.4-20241105.073505-1266-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptYwxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_ywxx")
public class GxTcJcptYwxx {
    @Id
    private String ywid;
    private String bjbh;
    private String djlx;
    private String djzlx;
    private String sqsj;
    private String bsqd;
    private String cjrmc;
    private String cjrjs;
    private String cjly;
    private String djyy;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjzlx() {
        return djzlx;
    }

    public void setDjzlx(String djzlx) {
        this.djzlx = djzlx;
    }

    public String getSqsj() {
        return sqsj;
    }

    public void setSqsj(String sqsj) {
        this.sqsj = sqsj;
    }

    public String getBsqd() {
        return bsqd;
    }

    public void setBsqd(String bsqd) {
        this.bsqd = bsqd;
    }

    public String getCjrmc() {
        return cjrmc;
    }

    public void setCjrmc(String cjrmc) {
        this.cjrmc = cjrmc;
    }

    public String getCjrjs() {
        return cjrjs;
    }

    public void setCjrjs(String cjrjs) {
        this.cjrjs = cjrjs;
    }

    public String getCjly() {
        return cjly;
    }

    public void setCjly(String cjly) {
        this.cjly = cjly;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }
}

==> estateplat-common-1.2.4-20251027.081413-1311-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptYwxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_ywxx")
public class GxTcJcptYwxx {
    @Id
    private String ywid;
    private String bjbh;
    private String djlx;
    private String djzlx;
    private String sqsj;
    private String bsqd;
    private String cjrmc;
    private String cjrjs;
    private String cjly;
    private String djyy;

    private String slr;
    private String slrmc;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjzlx() {
        return djzlx;
    }

    public void setDjzlx(String djzlx) {
        this.djzlx = djzlx;
    }

    public String getSqsj() {
        return sqsj;
    }

    public void setSqsj(String sqsj) {
        this.sqsj = sqsj;
    }

    public String getBsqd() {
        return bsqd;
    }

    public void setBsqd(String bsqd) {
        this.bsqd = bsqd;
    }

    public String getCjrmc() {
        return cjrmc;
    }

    public void setCjrmc(String cjrmc) {
        this.cjrmc = cjrmc;
    }

    public String getCjrjs() {
        return cjrjs;
    }

    public void setCjrjs(String cjrjs) {
        this.cjrjs = cjrjs;
    }

    public String getCjly() {
        return cjly;
    }

    public void setCjly(String cjly) {
        this.cjly = cjly;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getSlr() {
        return slr;
    }

    public void setSlr(String slr) {
        this.slr = slr;
    }

    public String getSlrmc() {
        return slrmc;
    }

    public void setSlrmc(String slrmc) {
        this.slrmc = slrmc;
    }
}
